@@ -448,7 +448,7 @@ get_time (const gchar* format)
 }
 
 static void
-dialog_disposed (GObject *obj, gpointer dialog_pointer)
+dialog_destroyed (GObject *obj, gpointer dialog_pointer)
 {
 	pluma_debug (DEBUG_PLUGINS);
 
@@ -829,8 +829,8 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 			  G_CALLBACK (configure_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
-			  "dispose",
-			  G_CALLBACK (dialog_disposed),
+			  "destroy",
+			  G_CALLBACK (dialog_destroyed),
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
@@ -991,8 +991,8 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			  G_CALLBACK (choose_format_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
-			  "dispose",
-			  G_CALLBACK (dialog_disposed),
+			  "destroy",
+			  G_CALLBACK (dialog_destroyed),
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
