@@ -37,9 +37,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#ifdef WITH_MATEDESKTOP
-#include <libmate-desktop/mate-aboutdialog.h>
-#endif
 
 #include "pluma-commands.h"
 #include "pluma-debug.h"
@@ -80,18 +77,14 @@ void _pluma_cmd_help_about(GtkAction* action, PlumaWindow* window)
 		"Copyright \xc2\xa9 2003-2006 Paolo Maggi\n"
 		"Copyright \xc2\xa9 2004-2010 Paolo Borelli, Jesse van den Kieboom\nSteve Fr\303\251cinaux, Ignacio Casal Quinteiro\n"
 		"Copyright \xc2\xa9 2011 Perberos\n"
-		"Copyright \xc2\xa9 2012-2014 MATE developers";
+		"Copyright \xc2\xa9 2012-2016 MATE developers";
 
 	static const gchar comments[] = \
 		N_("Pluma is a small and lightweight text editor for the MATE Desktop");
 
 	pluma_debug (DEBUG_COMMANDS);
 
-#ifdef WITH_MATEDESKTOP
-	mate_show_about_dialog(GTK_WINDOW(window),
-#else
 	gtk_show_about_dialog(GTK_WINDOW(window),
-#endif
 		"program-name", "Pluma",
 
 		"authors", authors,
