@@ -55,6 +55,10 @@
 #define ALL_FILES		_("All Files")
 #define ALL_TEXT_FILES		_("All Text Files")
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 struct _PlumaFileChooserDialogPrivate
 {
 	GtkWidget *option_menu;
@@ -82,7 +86,11 @@ create_option_menu (PlumaFileChooserDialog *dialog)
 	GtkWidget *menu;
 
 	label = gtk_label_new_with_mnemonic (_("C_haracter Encoding:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+#endif
 
 	menu = pluma_encodings_combo_box_new (
 		gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
@@ -147,7 +155,11 @@ create_newline_combo (PlumaFileChooserDialog *dialog)
 	GtkTreeIter iter;
 
 	label = gtk_label_new_with_mnemonic (_("L_ine Ending:"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+#endif
 
 	store = gtk_list_store_new (2, G_TYPE_STRING, PLUMA_TYPE_DOCUMENT_NEWLINE_TYPE);
 	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
