@@ -43,6 +43,11 @@
 
 #define PLUMA_PANEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PLUMA_TYPE_PANEL, PlumaPanelPrivate))
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 struct _PlumaPanelPrivate 
 {
 	GtkOrientation orientation;
@@ -85,7 +90,11 @@ static GObject	*pluma_panel_constructor	(GType type,
 						 GObjectConstructParam *construct_properties);
 
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+G_DEFINE_TYPE(PlumaPanel, pluma_panel, GTK_TYPE_BOX)
+#else
 G_DEFINE_TYPE(PlumaPanel, pluma_panel, GTK_TYPE_VBOX)
+#endif
 
 static void
 pluma_panel_finalize (GObject *obj)
@@ -186,8 +195,13 @@ pluma_panel_class_init (PlumaPanelClass *klass)
 
 	g_object_class_install_property (object_class,
 					 PROP_ORIENTATION,
+#if GTK_CHECK_VERSION (3, 0, 0)
+					 g_param_spec_enum ("panel-orientation",
+							    "Panel Orientation",
+#else
 					 g_param_spec_enum ("orientation",
 							    "Orientation",
+#endif
 							    "The panel's orientation",
 							    GTK_TYPE_ORIENTATION,
 							    GTK_ORIENTATION_VERTICAL,
@@ -401,6 +415,11 @@ static void
 pluma_panel_init (PlumaPanel *panel)
 {
 	panel->priv = PLUMA_PANEL_GET_PRIVATE (panel);
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (panel),
+									GTK_ORIENTATION_VERTICAL);
+#endif
 }
 
 static void
@@ -528,7 +547,11 @@ build_vertical_panel (PlumaPanel *panel)
 			    0);	
 
 	panel->priv->title_label = gtk_label_new (_("Empty"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (panel->priv->title_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (panel->priv->title_label), 0, 0.5);
+#endif
 	gtk_label_set_ellipsize(GTK_LABEL (panel->priv->title_label), PANGO_ELLIPSIZE_END);
 
 	gtk_box_pack_start (GTK_BOX (icon_name_hbox),
@@ -626,8 +649,19 @@ build_tab_label (PlumaPanel  *panel,
 
 	/* setup label */
         label = gtk_label_new (name);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-        gtk_misc_set_padding (GTK_MISC (label), 0, 0);
+#endif
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_margin_start (label, 0);
+	gtk_widget_set_margin_end (label, 0);
+	gtk_widget_set_margin_top (label, 0);
+	gtk_widget_set_margin_bottom (label, 0);
+#else
+	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
+#endif
 	gtk_box_pack_start (GTK_BOX (label_hbox), label, TRUE, TRUE, 0);
 
 	gtk_widget_set_tooltip_text (label_ebox, name);
@@ -693,7 +727,11 @@ pluma_panel_add_item (PlumaPanel  *panel,
 	tab_label = build_tab_label (panel, item, data->name, data->icon);
 
 	menu_label = gtk_label_new (name);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (menu_label), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (menu_label), 0.0, 0.5);
+#endif
 
 	if (!gtk_widget_get_visible (item))
 		gtk_widget_show (item);
